pub enum RemoteFocusOperation {
Viewport,
Sequential(SequentialFocusDirection, Option<BrowsingContextId>),
}Expand description
The type of focus operation to do on a remote document.
Variants
Viewport
Focus the entire viewport of the remote document.
Sequential(SequentialFocusDirection, Option<BrowsingContextId>)
Do sequential focus navigation using the <iframe> element with the given
BrowsingContextId as the starting point and in the given direction.